@@ -70,8 +70,8 @@ pub enum NodeEvent {
         /// Whether store failed due to full
         full: bool,
     },
-    /// Inform Adults of a possible deviant node
-    DeviantsDetected(BTreeSet<XorName>),
+    /// Inform Adults of a possible suspect node
+    SuspiciousNodesDetected(BTreeSet<XorName>),
 }
 
 /// Query originating at a node
