@@ -17,13 +17,13 @@ use crate::node::{
 };
 use crate::types::{log_markers::LogMarker, Peer};
 
-use std::{sync::Arc, time::Duration};
+use std::{collections::BTreeSet, sync::Arc, time::Duration};
 use tokio::time::MissedTickBehavior;
 use tokio::{sync::watch, time};
 use tracing::Instrument;
 
 const PROBE_INTERVAL: Duration = Duration::from_secs(30);
-const LINK_CLEANUP_INTERVAL: Duration = Duration::from_secs(15);
+const CLEANUP_INTERVAL: Duration = Duration::from_secs(60);
 
 // A command/subcommand id e.g. "963111461", "963111461.0"
 type CmdId = String;
@@ -143,7 +143,7 @@ impl Dispatcher {
         info!("Starting cleaning up network links");
         let _handle = tokio::spawn(async move {
             let dispatcher = self.clone();
-            let mut interval = tokio::time::interval(LINK_CLEANUP_INTERVAL);
+            let mut interval = tokio::time::interval(CLEANUP_INTERVAL);
             interval.set_missed_tick_behavior(MissedTickBehavior::Skip);
 
             loop {
@@ -159,6 +159,56 @@ impl Dispatcher {
             }
         });
     }
+    pub(super) async fn check_for_dysfunction_periodically(self: Arc<Self>) {
+        info!("Starting dysfunction checking");
+        let _handle = tokio::spawn(async move {
+            let dispatcher = self.clone();
+            let mut interval = tokio::time::interval(CLEANUP_INTERVAL);
+            interval.set_missed_tick_behavior(MissedTickBehavior::Skip);
+
+            loop {
+                let _instant = interval.tick().await;
+
+                let unresponsive_nodes = match dispatcher.node.get_dysfunctional_node_names().await
+                {
+                    Ok(nodes) => nodes,
+                    Err(error) => {
+                        error!("Error getting dysfunctional nodes: {error}");
+                        BTreeSet::default()
+                    }
+                };
+
+                if !unresponsive_nodes.is_empty() {
+                    debug!("{:?} : {unresponsive_nodes:?}", LogMarker::ProposeOffline);
+                    let cmd = Cmd::ProposeOffline(unresponsive_nodes);
+                    if let Err(e) = dispatcher
+                        .clone()
+                        .enqueue_and_handle_next_cmd_and_offshoots(cmd, None)
+                        .await
+                    {
+                        error!("Error sending Propose Offline for dysfunctional nodes: {e:?}");
+                    }
+                }
+
+                match dispatcher.node.notify_about_newly_suspect_nodes().await {
+                    Ok(suspect_cmds) => {
+                        for cmd in suspect_cmds {
+                            if let Err(e) = dispatcher
+                                .clone()
+                                .enqueue_and_handle_next_cmd_and_offshoots(cmd, None)
+                                .await
+                            {
+                                error!("Error processing suspect node cmds: {:?}", e);
+                            }
+                        }
+                    }
+                    Err(error) => {
+                        error!("Error getting suspect nodes: {error}");
+                    }
+                };
+            }
+        });
+    }
 
     pub(super) async fn write_prefixmap_to_disk(self: Arc<Self>) {
         info!("Writing our PrefixMap to disk");
@@ -335,14 +385,13 @@ impl Dispatcher {
                     .send_accepted_online_share(peer, previous_name)
                     .await
             }
-            Cmd::ProposeOffline(name) => self.node.propose_offline(name).await,
+            Cmd::ProposeOffline(names) => self.node.cast_offline_proposals(&names).await,
             Cmd::StartConnectivityTest(name) => Ok(vec![
                 self.node
                     .send_msg_to_our_elders(SystemMsg::StartConnectivityTest(name))
                     .await?,
             ]),
             Cmd::TestConnectivity(name) => {
-                let mut cmds = vec![];
                 if let Some(member_info) = self
                     .node
                     .network_knowledge()
@@ -356,10 +405,10 @@ impl Dispatcher {
                         .await
                         .is_err()
                     {
-                        cmds.push(Cmd::ProposeOffline(member_info.name()));
+                        self.node.log_comm_issue(member_info.name()).await?
                     }
                 }
-                Ok(cmds)
+                Ok(vec![])
             }
         }
     }
